==> haskell-tamarin-prover-utils-1.2.2-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-tamarin-prover-utils.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tamarin-prover-utils
version: 1.2.2
id: tamarin-prover-utils-1.2.2-29rprtoxIif8oIayhAyrJZ
key: tamarin-prover-utils-1.2.2-29rprtoxIif8oIayhAyrJZ
license: GPL
copyright: Benedikt Schmidt, Simon Meier, ETH Zurich, 2010-2012
maintainer: Simon Meier <simon.meier@inf.ethz.ch>
homepage: http://www.infsec.ethz.ch/research/software/tamarin
synopsis: Utility library for the tamarin prover.
description:
    This is an internal library of the Tamarin prover for
    security protocol verification
    (<hackage.haskell.org/package/tamarin-prover>).
category: Theorem Provers
author: Benedikt Schmidt <benedikt.schmidt@inf.ethz.ch>,
        Simon Meier <simon.meier@inf.ethz.ch>
exposed: True
indefinite: False
exposed-modules:
    Control.Basics Control.Monad.Bind Control.Monad.Disj
    Control.Monad.Fresh Control.Monad.Trans.FastFresh
    Control.Monad.Trans.PreciseFresh Data.Color Data.DAG.Simple
    Debug.Trace.Ignore Extension.Data.Bounded Extension.Data.ByteString
    Extension.Data.Label Extension.Data.Monoid Extension.Prelude
    Logic.Connectives System.Timing Text.Dot Text.PrettyPrint.Class
    Text.PrettyPrint.Highlight Text.PrettyPrint.Html Text.Unicode
    Utils.Misc
hidden-modules: Control.Monad.Fresh.Class Control.Monad.Trans.Disj
                Control.Monad.Disj.Class
abi: b788d5f5d829b9cdab72c705751492a0
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/tamarin-prover-utils-1.2.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/tamarin-prover-utils-1.2.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/tamarin-prover-utils-1.2.2
hs-libraries: HStamarin-prover-utils-1.2.2-29rprtoxIif8oIayhAyrJZ
depends:
    SHA-1.6.4.2-1gNz0XEXVc9D2LWQ8o29zI base-4.10.1.0
    base64-bytestring-1.0.0.1-8MlzMz2YH3lCqJ4GOwL1Be binary-0.8.5.1
    blaze-builder-0.4.0.2-ClyQj7ny9rnJd2QFCbHKRH bytestring-0.10.8.2
    containers-0.5.10.2 deepseq-1.4.3.0
    dlist-0.8.0.3-3sLvqWTqZxIC2tgTx4QBVJ
    fclabels-2.0.3.2-4PbsFDjds23DVWcXML4X3o
    mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH pretty-1.1.3.3
    syb-0.7-3Lq8MQxmYP07qktjI1jxu0 time-1.8.0.2 transformers-0.5.2.0
abi-depends: SHA-1.6.4.2-1gNz0XEXVc9D2LWQ8o29zI=a1e214e4043a6e8594f125021a39000f
             base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             base64-bytestring-1.0.0.1-8MlzMz2YH3lCqJ4GOwL1Be=fd5db0dc9688093c1ac2c3223371478e
             binary-0.8.5.1=33c677d3ced9a5afbc7b354509494653
             blaze-builder-0.4.0.2-ClyQj7ny9rnJd2QFCbHKRH=9a0562647033c21b2abf88c991a65d08
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             deepseq-1.4.3.0=e843b5d736cc095915bf2399fddf152e
             dlist-0.8.0.3-3sLvqWTqZxIC2tgTx4QBVJ=478549693a66e61496f47353d337a8f9
             fclabels-2.0.3.2-4PbsFDjds23DVWcXML4X3o=bfd3c04c8c1d27e4dcaaf345498c2321
             mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH=a1f89647d7228db4bf59b7aaec52e888
             pretty-1.1.3.3=229bcf5342145ac1755207fe83d29780
             syb-0.7-3Lq8MQxmYP07qktjI1jxu0=f985ea42a9fa578e0f67572a93e19b5d
             time-1.8.0.2=d7392e85059cb108aeb68d6e24815970
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
haddock-interfaces: /usr/share/doc/haskell-tamarin-prover-utils/html/tamarin-prover-utils.haddock
haddock-html: /usr/share/doc/haskell-tamarin-prover-utils/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tamarin-prover-utils-1.2.2-6-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-tamarin-prover-utils.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tamarin-prover-utils
version: 1.2.2
id: tamarin-prover-utils-1.2.2-1QeHe6tKB7rHwJD9OzqSpO
key: tamarin-prover-utils-1.2.2-1QeHe6tKB7rHwJD9OzqSpO
license: GPL
copyright: Benedikt Schmidt, Simon Meier, ETH Zurich, 2010-2012
maintainer: Simon Meier <simon.meier@inf.ethz.ch>
homepage: http://www.infsec.ethz.ch/research/software/tamarin
synopsis: Utility library for the tamarin prover.
description:
    This is an internal library of the Tamarin prover for
    security protocol verification
    (<hackage.haskell.org/package/tamarin-prover>).
category: Theorem Provers
author: Benedikt Schmidt <benedikt.schmidt@inf.ethz.ch>,
        Simon Meier <simon.meier@inf.ethz.ch>
exposed: True
indefinite: False
exposed-modules:
    Control.Basics Control.Monad.Bind Control.Monad.Disj
    Control.Monad.Fresh Control.Monad.Trans.FastFresh
    Control.Monad.Trans.PreciseFresh Data.Color Data.DAG.Simple
    Debug.Trace.Ignore Extension.Data.Bounded Extension.Data.ByteString
    Extension.Data.Label Extension.Data.Monoid Extension.Prelude
    Logic.Connectives System.Timing Text.Dot Text.PrettyPrint.Class
    Text.PrettyPrint.Highlight Text.PrettyPrint.Html Text.Unicode
    Utils.Misc
hidden-modules: Control.Monad.Fresh.Class Control.Monad.Trans.Disj
                Control.Monad.Disj.Class
abi: 9d6221b2015bff2958a5adaa508709d6
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/tamarin-prover-utils-1.2.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/tamarin-prover-utils-1.2.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/tamarin-prover-utils-1.2.2
hs-libraries: HStamarin-prover-utils-1.2.2-1QeHe6tKB7rHwJD9OzqSpO
depends:
    SHA-1.6.4.2-1gNz0XEXVc9D2LWQ8o29zI base-4.10.1.0
    base64-bytestring-1.0.0.1-8MlzMz2YH3lCqJ4GOwL1Be binary-0.8.5.1
    blaze-builder-0.4.0.2-DHYoGQYzHva8PydFQisCY7 bytestring-0.10.8.2
    containers-0.5.10.2 deepseq-1.4.3.0
    dlist-0.8.0.3-3sLvqWTqZxIC2tgTx4QBVJ
    fclabels-2.0.3.2-4PbsFDjds23DVWcXML4X3o
    mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH pretty-1.1.3.3
    syb-0.7-3Lq8MQxmYP07qktjI1jxu0 time-1.8.0.2 transformers-0.5.2.0
abi-depends: SHA-1.6.4.2-1gNz0XEXVc9D2LWQ8o29zI=a1e214e4043a6e8594f125021a39000f
             base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             base64-bytestring-1.0.0.1-8MlzMz2YH3lCqJ4GOwL1Be=fd5db0dc9688093c1ac2c3223371478e
             binary-0.8.5.1=33c677d3ced9a5afbc7b354509494653
             blaze-builder-0.4.0.2-DHYoGQYzHva8PydFQisCY7=4ded867b3c298ec132dad2104a7f7b70
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             deepseq-1.4.3.0=e843b5d736cc095915bf2399fddf152e
             dlist-0.8.0.3-3sLvqWTqZxIC2tgTx4QBVJ=478549693a66e61496f47353d337a8f9
             fclabels-2.0.3.2-4PbsFDjds23DVWcXML4X3o=bfd3c04c8c1d27e4dcaaf345498c2321
             mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH=a1f89647d7228db4bf59b7aaec52e888
             pretty-1.1.3.3=229bcf5342145ac1755207fe83d29780
             syb-0.7-3Lq8MQxmYP07qktjI1jxu0=f985ea42a9fa578e0f67572a93e19b5d
             time-1.8.0.2=d7392e85059cb108aeb68d6e24815970
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
haddock-interfaces: /usr/share/doc/haskell-tamarin-prover-utils/html/tamarin-prover-utils.haddock
haddock-html: /usr/share/doc/haskell-tamarin-prover-utils/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
